<?php
/*
 * @package Twenty Minutes
 */

function twenty_minutes_admin_enqueue_scripts() {
	wp_enqueue_style( 'twenty-minutes-admin-style', esc_url( get_template_directory_uri() ).'/css/addon.css' );
}
add_action( 'admin_enqueue_scripts', 'twenty_minutes_admin_enqueue_scripts' );

add_action('after_switch_theme', 'twenty_minutes_options');

function twenty_minutes_options () {
	global $pagenow;
	if( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) && current_user_can( 'manage_options' ) ) {
		wp_redirect( admin_url( 'themes.php?page=twenty-minutes' ) );
		exit;
	}
}

if ( ! defined( 'TWENTY_MINUTES_SUPPORT' ) ) {
define('TWENTY_MINUTES_SUPPORT',__('https://wordpress.org/support/theme/twenty-minutes','twenty-minutes'));
}
if ( ! defined( 'TWENTY_MINUTES_REVIEW' ) ) {
define('TWENTY_MINUTES_REVIEW',__('https://wordpress.org/support/theme/twenty-minutes/reviews/#new-post','twenty-minutes'));
}
if ( ! defined( 'TWENTY_MINUTES_PRO_DEMO' ) ) {
define('TWENTY_MINUTES_PRO_DEMO',__('https://www.theclassictemplates.com/demo/twenty-minutes/','twenty-minutes'));
}
if ( ! defined( 'TWENTY_MINUTES_THEME_PAGE' ) ) {
define('TWENTY_MINUTES_THEME_PAGE',__('https://www.theclassictemplates.com/themes/','twenty-minutes'));
}
if ( ! defined( 'TWENTY_MINUTES_PREMIUM_PAGE' ) ) {
define('TWENTY_MINUTES_PREMIUM_PAGE',__('https://www.theclassictemplates.com/wp-themes/twenty-minutes-wordpress-template/','twenty-minutes'));
}

function twenty_minutes_theme_info_menu_link() {

	$theme = wp_get_theme();
	add_theme_page(
		sprintf( esc_html__( 'Welcome to %1$s %2$s', 'twenty-minutes' ), $theme->display( 'Name' ), $theme->display( 'Version' ) ),
		esc_html__( 'Theme Info', 'twenty-minutes' ),'edit_theme_options','twenty-minutes','twenty_minutes_theme_info_page'
	);
}
add_action( 'admin_menu', 'twenty_minutes_theme_info_menu_link' );

function twenty_minutes_theme_info_page() {

	$theme = wp_get_theme();
	?>
<div class="wrap theme-info-wrap">
	<h1><?php printf( esc_html__( 'Welcome to %1$s %2$s', 'twenty-minutes' ), esc_html($theme->display( 'Name', 'twenty-minutes'  )),esc_html($theme->display( 'Version', 'twenty-minutes' ))); ?>
	</h1>
	<p class="theme-description">
	<?php esc_html_e( 'Do you want to configure this theme? Look no further, our easy-to-follow theme documentation will walk you through it.', 'twenty-minutes' ); ?>
	</p>
	<hr>
	<div class="important-links clearfix">
		<p><strong><?php esc_html_e( 'Theme Links', 'twenty-minutes' ); ?>:</strong>
			<a href="<?php echo esc_url( TWENTY_MINUTES_THEME_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Theme Page', 'twenty-minutes' ); ?></a>
			<a href="<?php echo esc_url( TWENTY_MINUTES_SUPPORT ); ?>" target="_blank"><?php esc_html_e( 'Contact Us', 'twenty-minutes' ); ?></a>
			<a href="<?php echo esc_url( TWENTY_MINUTES_REVIEW ); ?>" target="_blank"><?php esc_html_e( 'Rate This Theme', 'twenty-minutes' ); ?></a>
			<a href="<?php echo esc_url( TWENTY_MINUTES_PRO_DEMO ); ?>" target="_blank"><?php esc_html_e( 'Premium Demo', 'twenty-minutes' ); ?></a>
			<a href="<?php echo esc_url( TWENTY_MINUTES_PREMIUM_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Go To Premium', 'twenty-minutes' ); ?></a>
		</p>
	</div>
	<hr>
	<div id="getting-started">
		<h3><?php printf( esc_html__( 'Getting started with %s', 'twenty-minutes' ), 
		esc_html($theme->display( 'Name', 'twenty-minutes' ))); ?></h3>
		<div class="columns-wrapper clearfix">
			<div class="column column-half clearfix">
				<div class="section">
					<h4><?php esc_html_e( 'Theme Description', 'twenty-minutes' ); ?></h4>
					<div class="theme-description-1"><?php echo esc_html($theme->display( 'Description' )); ?></div>
				</div>
			</div>
			<div class="column column-half clearfix">
				<img src="<?php echo esc_url( $theme->get_screenshot() ); ?>" />
				<div class="section">
					<h4><?php esc_html_e( 'Theme Options', 'twenty-minutes' ); ?></h4>
					<p class="about">
					<?php printf( esc_html__( '%s makes use of the Customizer for all theme settings. Click on "Customize Theme" to open the Customizer now.', 'twenty-minutes' ),esc_html($theme->display( 'Name', 'twenty-minutes' ))); ?></p>
					<p>
					<a target="_blank" href="<?php echo esc_url( wp_customize_url() ); ?>" class="button button-primary"><?php esc_html_e( 'Customize Theme', 'twenty-minutes' ); ?></a>
					<a href="<?php echo esc_url( TWENTY_MINUTES_PREMIUM_PAGE ); ?>" target="_blank" class="button button-secondary premium-btn"><?php esc_html_e( 'Checkout Premium', 'twenty-minutes' ); ?></a></p>
				</div>
			</div>
		</div>
	</div>
	<hr>
	<div id="theme-author">
	  <p><?php
		printf( esc_html__( '%1$s is proudly brought to you by %2$s. If you like this theme, %3$s :)', 'twenty-minutes' ),
			esc_html($theme->display( 'Name', 'twenty-minutes' )),
			'<a target="_blank" href="' . esc_url( 'https://www.theclassictemplates.com/', 'twenty-minutes' ) . '">classictemplate</a>',
			'<a target="_blank" href="' . esc_url( TWENTY_MINUTES_REVIEW ) . '" title="' . esc_attr__( 'Rate it', 'twenty-minutes' ) . '">' . esc_html_x( 'rate it', 'If you like this theme, rate it', 'twenty-minutes' ) . '</a>'
		)
		?></p>
	</div>
</div>
<?php
}
